@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     TestData.py
@@ -17,26 +15,22 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'March 2013'
-__copyright__ = '(C) 2013, Victor Olaya'
-
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
+__author__ = "Victor Olaya"
+__date__ = "March 2013"
+__copyright__ = "(C) 2013, Victor Olaya"
 
 import os.path
 
-testDataPath = os.path.join(os.path.dirname(__file__), 'testdata')
+testDataPath = os.path.join(os.path.dirname(__file__), "testdata")
 
 
 def table():
-    return os.path.join(testDataPath, 'table.dbf')
+    return os.path.join(testDataPath, "table.dbf")
 
 
 def points():
-    return os.path.join(testDataPath, 'points.gml')
+    return os.path.join(testDataPath, "points.gml")
 
 
 def invalid_geometries():
-    return os.path.join(testDataPath, 'invalidgeometries.gml')
+    return os.path.join(testDataPath, "invalidgeometries.gml")
